@@ -3,7 +3,7 @@ from iot_rdb.util import IotRedisBasic
 from iot_rdb.util import IotRedisPublisher
 from iot_rdb.util import IotRedisSubscriber
 from iot_rdb.util import IotRedisPubSub
-__version__ = "0.1.4"
+__version__ = "0.1.6"
 
 
 class IotRedisCommon:
@@ -29,7 +29,7 @@ class IotRedisCommon:
 
     class CrossConnection:
         OPCUA = ("control_input", "init_vars")
-        CONTROLLER = ("raw_outputs", "filtered_outputs")
+        CONTROLLER = ("raw_outputs", "perturbations", "filtered_outputs", "inputs")
         AUTOENCODER = ("raw_outputs", "perturbations", "inputs")
         DB = ("raw_outputs", "filtered_outputs", "perturbations", "inputs")
         DBDRIVER = ("raw_outputs", "filtered_outputs", "perturbations", "inputs")
