@@ -103,6 +103,16 @@ class IotRedisSubscriber(IotRedisBasic, Thread):
                 print("Connected to subscribe")
                 break
 
+    def unsubscribe_channels(self, *channels_to_unsubscribe: str) -> None:
+        try:
+            self.pubsub.unsubscribe(channels_to_unsubscribe)
+        except ConnectionError as err:
+            print(f"Error trying to unsusbscribe to server: {err}")
+            time.sleep(1)
+        else:
+            print("Unsubscribe to: ", end="")
+            print(channels_to_unsubscribe)
+
     def data_available(self) -> bool:
         return not self.data_list.empty()
 
